# Copyright 2019-2020 Alexander Polishchuk
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from rest_framework import routers

from django_obm import views


def register_views(router):
    router.register(r"transactions", views.TransactionViewSet)
    router.register(r"currencies", views.CurrencyViewSet)
    router.register(r"addresses", views.AddressViewSet)
    return router


urlpatterns = register_views(routers.SimpleRouter()).urls
